==> haskell-fsnotify-0.4.4.0-29-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.4.4.0
visibility:           public
id:                   fsnotify-0.4.4.0-1zmDynlNT35FFGTVQ4jtQH
key:                  fsnotify-0.4.4.0-1zmDynlNT35FFGTVQ4jtQH
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification, and deletion notification. This library builds upon existing libraries for platform-specific Windows, Mac, and Linux filesystem event notification.

category:             Filesystem
abi:                  a3bf698972e7e565d96d21ed3a3a5f25
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Find System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
    System.FSNotify.Linux.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/fsnotify-0.4.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fsnotify-0.4.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fsnotify-0.4.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify
hs-libraries:         HSfsnotify-0.4.4.0-1zmDynlNT35FFGTVQ4jtQH
depends:
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    filepath-1.4.300.1 hinotify-0.4.2-KBVoaFnxvyh4b67Iw9rVOg
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI text-2.0.2
    time-1.12.2 unix-2.8.4.0 unix-compat-0.7.4.1-FrCbkIkHqC8LnfXFaiVUhh

haddock-interfaces:   /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify-0.4.4.0-30-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.4.4.0
visibility:           public
id:                   fsnotify-0.4.4.0-IPbL2aIEyJBDpStmRnbeT6
key:                  fsnotify-0.4.4.0-IPbL2aIEyJBDpStmRnbeT6
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification, and deletion notification. This library builds upon existing libraries for platform-specific Windows, Mac, and Linux filesystem event notification.

category:             Filesystem
abi:                  1e934f0456a92a20b9990c308f84f9b2
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Find System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
    System.FSNotify.Linux.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/fsnotify-0.4.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fsnotify-0.4.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fsnotify-0.4.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify
hs-libraries:         HSfsnotify-0.4.4.0-IPbL2aIEyJBDpStmRnbeT6
depends:
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    filepath-1.4.300.1 hinotify-0.4.2-7jy9U7hnF2eLSCmgfLuzWk
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI text-2.0.2
    time-1.12.2 unix-2.8.4.0 unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq

haddock-interfaces:   /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
